@@ -8,7 +8,10 @@ from .core import \
     OneOf, \
     Pattern, \
     Remaining, \
+    Some, \
     Strict, \
+    String, \
+    StringPattern, \
     match
 
 from .patterns import \
